@@ -541,7 +541,7 @@ SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payl
 				char tmp[30];
 				snprintf(tmp,sizeof(tmp),"ptime=%i",payload->a_ptime);
 				payload_type_append_send_fmtp(rtppayload,tmp);
-				ms_message("%s attribute added to fmtp");
+				ms_message("%s attribute added to fmtp",tmp);
 			}
 		}
 		return ret;
