@@ -300,6 +300,12 @@ net_config_read (LinphoneCore *lc)
 	linphone_core_set_firewall_policy(lc,tmp);
 	tmp=lp_config_get_int(lc->config,"net","nat_sdp_only",0);
 	lc->net_conf.nat_sdp_only=tmp;
+	tmp=lp_config_get_int(lc->config,"net","mtu",0);
+	if (tmp>0){
+		int pmax=tmp-40-8-12;
+		ms_message("MTU is %i, rtp payload max size will be %i",tmp,pmax);
+		ms_set_payload_max_size(pmax);
+	}
 }
 
 
@@ -312,13 +318,14 @@ void sound_config_read(LinphoneCore *lc)
 	const char **devices;
 	int ndev;
 	int i;
-
+#ifndef WIN32
 	/*alsadev let the user use custom alsa device within linphone*/
 	devid=lp_config_get_string(lc->config,"sound","alsadev",NULL);
 	if (devid){
 		MSSndCard *card=ms_alsa_card_new_custom(devid,devid);
 		ms_snd_card_manager_add_card(ms_snd_card_manager_get(),card);
 	}
+#endif
 	/* retrieve all sound devices */
 	elem=ms_snd_card_manager_get_list(ms_snd_card_manager_get());
 	ndev=ms_list_size(elem);
@@ -620,6 +627,7 @@ void linphone_core_init (LinphoneCore * lc, const LinphoneCoreVTable *vtable, co
 	rtp_profile_set_payload(&av_profile,98,&payload_type_h263_1998);
 	rtp_profile_set_payload(&av_profile,99,&payload_type_mp4v);
 	rtp_profile_set_payload(&av_profile,100,&payload_type_x_snow);
+	rtp_profile_set_payload(&av_profile,102,&payload_type_h264);
 #endif
 
 	ms_init();
@@ -938,18 +946,12 @@ static void display_bandwidth(RtpSession *as, RtpSession *vs){
 void linphone_core_iterate(LinphoneCore *lc)
 {
 	eXosip_event_t *ev;
-#ifdef AMD
-	printf("entering linphone_core_iterate()\n");
-#endif
 	if (lc->preview_finished){
 		lc->preview_finished=0;
 		ring_stop(lc->ringstream);
 		lc->ringstream=NULL;
 		lc_callback_obj_invoke(&lc->preview_finished_cb,lc);
 	}
-#ifdef AMD
-	printf("getting eXosip event...\n");
-#endif
 	
 	if (exosip_running){
 		while((ev=eXosip_event_wait(0,0))!=NULL){
@@ -978,18 +980,18 @@ void linphone_core_iterate(LinphoneCore *lc)
 					vs=lc->videostream->session;
 				display_bandwidth(as,vs);
 			}
+			if (lc->videostream!=NULL)
+				video_stream_iterate(lc->videostream);
 		}
 	}
 	if (linphone_core_video_preview_enabled(lc)){
 		if (lc->previewstream==NULL)
 			toggle_video_preview(lc,TRUE);
+		else video_stream_iterate(lc->previewstream);
 	}else{
 		if (lc->previewstream!=NULL)
 			toggle_video_preview(lc,FALSE);
 	}
-#ifdef AMD
-	printf("iterate done...\n");
-#endif
 }
 
 
@@ -1729,7 +1731,7 @@ void linphone_core_send_dtmf(LinphoneCore *lc,char dtmf)
 		snprintf(dtmf_body, 999, "Signal=%c\r\nDuration=250\r\n", dtmf);
 		osip_message_set_body(msg,dtmf_body,strlen(dtmf_body));
 		osip_message_set_content_type(msg,"application/dtmf-relay");
-		snprintf(clen,sizeof(clen),"%i",strlen(dtmf_body));
+		snprintf(clen,sizeof(clen),"%lu",(unsigned long)strlen(dtmf_body));
 		osip_message_set_content_length(msg,clen);
 		
 		eXosip_lock();
