@@ -19,7 +19,7 @@ Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
  */
  
 #include "linphonecore.h"
-#include <eXosip.h>
+#include <eXosip2/eXosip.h>
 #include <osipparser2/osip_message.h>
 #include "lpconfig.h"
 #include "private.h"
@@ -51,10 +51,11 @@ void linphone_proxy_config_destroy(LinphoneProxyConfig *obj){
 }
 
 static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
+	osip_message_t *msg;
 	eXosip_lock();
-	eXosip_register(obj->rid,obj->expires);
+	eXosip_register_build_register(obj->rid,obj->expires,&msg);
+	eXosip_register_send_register(obj->rid,msg);
 	eXosip_unlock();
-	obj->reg_time=time(NULL);
 }
 
 
@@ -148,14 +149,12 @@ void linphone_proxy_config_edit(LinphoneProxyConfig *obj){
 	if (obj->reg_sendregister){
 		/* unregister */
 		if (obj->registered) {
+			osip_message_t *msg;
 			eXosip_lock();
-			/* obj->expires = 0; fixed by amd 27/MARCH/2005 */
-			eXosip_register(obj->rid,0);
-			
-#if 0
-			obj->rid=-1;
-#endif
+			eXosip_register_build_register(obj->rid,0,&msg);
+			eXosip_register_send_register(obj->rid,msg);
 			eXosip_unlock();
+			obj->registered=FALSE;
 		}
 	}
 }
@@ -174,23 +173,9 @@ void linphone_proxy_config_done(LinphoneProxyConfig *obj)
 	obj->frozen=FALSE;
 	if (obj->reg_sendregister){
 		char *ct=NULL;
-		#if 0
-		{
-			char localip[LINPHONE_IPADDR_SIZE];
-			linphone_core_get_local_ip(obj->lc,NULL,localip);
-			osip_from_t *identity;
-			osip_from_init(&identity);
-			osip_from_parse(identity,id_str);
-			osip_free(identity->url->host);
-			identity->url->host=osip_strdup(localip);
-			identity->url->port=osip_malloc(15);
-			snprintf(identity->url->port, 15, "%i", obj->lc->sip_conf.sip_port);
-			osip_from_to_str(identity,&ct);
-			osip_from_free(identity);
-		}
-		#endif 
-		obj->rid=eXosip_register_init((char*)id_str,obj->reg_proxy,ct,obj->reg_route);
-		linphone_proxy_config_register(obj);
+		osip_message_t *msg=NULL;
+		obj->rid=eXosip_register_build_initial_register(id_str,obj->reg_proxy,NULL,obj->expires,&msg);
+		eXosip_register_send_register(obj->rid,msg);
 		if (ct!=NULL) osip_free(ct);
 	}
 }
@@ -204,24 +189,6 @@ void linphone_proxy_config_set_realm(LinphoneProxyConfig *cfg, const char *realm
 	if (realm!=NULL) cfg->realm=ms_strdup(realm);
 }
 
-void linphone_core_update_proxy_register(LinphoneCore *lc){
-	const MSList *elem;
-	for(elem=linphone_core_get_proxy_config_list(lc);elem!=NULL;elem=ms_list_next(elem)){
-		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*) elem->data;
-		if (cfg->reg_sendregister && cfg->rid>=0){
-			if ( (time(NULL)-cfg->reg_time) > cfg->expires){
-				/* update the registration */
-				linphone_proxy_config_register(cfg);
-			}
-			else if (time(NULL)-cfg->reg_time > 200) {
-				/* update the registration more often */
-				linphone_proxy_config_register(cfg);
-			}
-		}
-	}
-}
-
-
 int linphone_proxy_config_send_publish(LinphoneProxyConfig *proxy,
 			       LinphoneOnlineStatus presence_mode)
 {
@@ -482,8 +449,8 @@ void linphone_proxy_config_write_to_config_file(LpConfig *config, LinphoneProxyC
 	char key[50];
 
 	sprintf(key,"proxy_%i",index);
+	lp_config_clean_section(config,key);
 	if (obj==NULL){
-		lp_config_clean_section(config,key);
 		return;
 	}
 	if (obj->reg_proxy!=NULL){
