@@ -20,21 +20,31 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef msvideoout_h
 #define msvideoout_h
 
-#include "msfilter.h"
+#include <mediastreamer2/msfilter.h>
+#include <mediastreamer2/msvideo.h>
 
-typedef struct _MSFrameBuffer{
-	int w,h;/* set by MSVideoOut */
-	uint8_t *y,*u,*v;/* set in return of init() by the MSDisplay*/
-} MSFrameBuffer;
 
 struct _MSDisplay;
 
+typedef enum _MSDisplayEventType{
+	MS_DISPLAY_RESIZE_EVENT
+}MSDisplayEventType;
+
+typedef struct _MSDisplayEvent{
+	MSDisplayEventType evtype;
+	int w,h;
+}MSDisplayEvent;
+
 typedef struct _MSDisplayDesc{
-	bool_t (*init)(struct _MSDisplay *, MSFrameBuffer *frame_buffer);
+	/*init requests setup of the display window at the proper size, given
+	in frame_buffer argument. Memory buffer (data,strides) must be fulfilled
+	at return. init() might be called several times upon screen resize*/
+	bool_t (*init)(struct _MSDisplay *, MSPicture *frame_buffer);
 	void (*lock)(struct _MSDisplay *);/*lock before writing to the framebuffer*/
 	void (*unlock)(struct _MSDisplay *);/*unlock after writing to the framebuffer*/
 	void (*update)(struct _MSDisplay *); /*display the picture to the screen*/
 	void (*uninit)(struct _MSDisplay *);
+	bool_t (*pollevent)(struct _MSDisplay *, MSDisplayEvent *ev);
 }MSDisplayDesc;
 
 typedef struct _MSDisplay{
@@ -48,6 +58,7 @@ typedef struct _MSDisplay{
 #define ms_display_lock(d)	if ((d)->desc->lock) (d)->desc->lock(d)
 #define ms_display_unlock(d)	if ((d)->desc->unlock) (d)->desc->unlock(d)
 #define ms_display_update(d)	if ((d)->desc->update) (d)->desc->update(d)
+bool_t ms_display_poll_event(MSDisplay *d, MSDisplayEvent *ev);
 
 extern MSDisplayDesc ms_sdl_display_desc;
 
@@ -72,6 +83,8 @@ void ms_display_set_window_id(MSDisplay *d, long window_id);
 void ms_display_destroy(MSDisplay *d);
 
 #define MS_VIDEO_OUT_SET_DISPLAY MS_FILTER_METHOD(MS_VIDEO_OUT_ID,0,MSDisplay*)
+#define MS_VIDEO_OUT_HANDLE_RESIZING MS_FILTER_METHOD_NO_ARG(MS_VIDEO_OUT_ID,1)
+#define MS_VIDEO_OUT_SET_CORNER MS_FILTER_METHOD(MS_VIDEO_OUT_ID,2,int*)
 
 #ifdef __cplusplus
 }
