@@ -19,6 +19,11 @@
 */
 
 
+#if defined(WIN32) || defined(_WIN32_WCE)
+#include "ortp-config-win32.h"
+#else
+#include "ortp-config.h"
+#endif
 #include "ortp/port.h"
 #include "ortp/ortp.h"
 #include "utils.h"
@@ -44,6 +49,10 @@ void * ortp_malloc0(size_t size){
 char * ortp_strdup(const char *tmp){
 #if	defined(_WIN32) || defined(_WIN32_WCE)
     return _strdup(tmp);
+#elif defined(__APPLE_CC__)
+    if (tmp==NULL)
+      return NULL;
+    return strdup(tmp);
 #else
     return strdup(tmp);
 #endif
@@ -124,6 +133,19 @@ int __ortp_thread_join(ortp_thread_t thread, void **ptr){
 	}
 	return err;
 }
+
+int __ortp_thread_create(pthread_t *thread, pthread_attr_t *attr, void * (*routine)(void*), void *arg){
+	pthread_attr_t my_attr;
+	pthread_attr_init(&my_attr);
+	if (attr)
+		my_attr = *attr;
+#ifdef ORTP_DEFAULT_THREAD_STACK_SIZE
+	if (ORTP_DEFAULT_THREAD_STACK_SIZE!=0)
+		pthread_attr_setstacksize(&my_attr, ORTP_DEFAULT_THREAD_STACK_SIZE);
+#endif
+	return pthread_create(thread, &my_attr, routine, arg);
+}
+
 #endif
 #if	defined(_WIN32) || defined(_WIN32_WCE)
 
